pub type SocketFactory = fn(SocketType, SocketProtocol) -> Result<Arc<dyn SocketObject>, SocketError>;Expand description
Socket factory function type
ABI modules register socket factories for their specific implementations
pub type SocketFactory = fn(SocketType, SocketProtocol) -> Result<Arc<dyn SocketObject>, SocketError>;Socket factory function type
ABI modules register socket factories for their specific implementations